@@ -29,6 +29,7 @@ io_csv <- function(x, ...)UseMethod('io_csv')
 #'
 #' @param x character file path; passed to \code{\link[csv]{as.csv.character}} (by method dispatch)
 #' @param ext extension for metadata equivalent of x
+#' @param meta explicit file path for metadata
 # @param coerce whether to coerce to factor where guide is a list; passed to \code{\link{decorate.data.frame}}
 #' @param ... passed to \code{\link[csv]{as.csv.character}} and to \code{\link{decorate}}
 #' @export
@@ -42,12 +43,15 @@ io_csv <- function(x, ...)UseMethod('io_csv')
 io_csv.character <- function(
   x,
   ext = getOption('yamlet_extension', '.yaml'),
+  meta = NULL,
   #coerce = getOption('yamlet_coerce', FALSE),
   ...
 ){
   d <- csv::as.csv(x, ...)
-  meta <- sub('\\.[^.]*$','',x) # remove last dot and any trailing chars
-  meta <- paste0(meta, ext)
+  if(is.null(meta)){
+    meta <- sub('\\.[^.]*$','',x) # remove last dot and any trailing chars
+    meta <- paste0(meta, ext)
+  }
   if(!file.exists(meta)){
     message('did not find ', meta)
   }else{
